@@ -1,8 +1,12 @@
-#!/bin/bash -ex
+#!/bin/bash
+
+set -euxo pipefail
+
+cd "$(dirname "$(realpath "$0")")"
 
 git submodule update --init --depth 1 --recursive
 
-if [ -z "$XDG_RUNTIME_DIR" ]; then
+if [ -z ${XDG_RUNTIME_DIR+x} ]; then
     export XDG_RUNTIME_DIR=/tmp
 fi
 
@@ -10,4 +14,4 @@ fi
 mkdir -p $XDG_RUNTIME_DIR/openssh_sftp_client/
 rm -rf $XDG_RUNTIME_DIR/openssh_sftp_client/*
 
-exec cargo test $@
+exec cargo test "$@"
